@@ -1,7 +1,10 @@
-from cryptomodel.cryptostore import user_transaction, OPERATIONS
+from cryptomodel.cryptostore import user_transaction
+from cryptomodel.operations import OPERATIONS
+
 from cryptodataaccess.Memory import Memory, TRANSACTIONS_MEMORY_KEY
 from cryptodataaccess.Repository import Repository
 
+
 class TransactionRepository(Repository):
 
     def __init__(self, transaction_store):
